@@ -181,12 +181,12 @@ void InitialPhraseBookWidget::initStandardPhraseBooks() {
    Q3ListViewItem *parent = 0;
    Q3ListViewItem *last = 0;
    QStringList currentNamePath;
-   currentNamePath<<"";
+   currentNamePath<<QString("");
    Q3PtrStack<Q3ListViewItem> stack;
    StandardBookList::iterator it;
    for (it = bookPaths.begin(); it != bookPaths.end(); ++it) {
       QString namePath = (*it).path;
-      QStringList dirs = namePath.split( "/");
+      QStringList dirs = namePath.split( '/');
 
       QStringList::iterator it1=currentNamePath.begin();
       QStringList::iterator it2=dirs.begin();
@@ -490,7 +490,7 @@ void PhraseBookDialog::initStandardPhraseBooks () {
       url.setPath((*it).filename);
 
       QString namePath = "x/"+(*it).path;
-      QStringList dirs = namePath.split( "/");
+      QStringList dirs = namePath.split( '/');
 
       QStringList::iterator it1=currentNamePath.begin();
       QStringList::iterator it2=dirs.begin();
