@@ -5,6 +5,7 @@
   ------------------------------
   Copyright:
   (C) 2006 by Gary Cramblitt <garycramblitt@comcast.net>
+  (C) 2009 by Jeremy Whiting <jpwhiting@kde.org>
   -------------------
   Original author: Gary Cramblitt <garycramblitt@comcast.net>
 
@@ -23,8 +24,8 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  ******************************************************************************/
 
-#ifndef _KSPEECH_H_
-#define _KSPEECH_H_
+#ifndef KSPEECH_H
+#define KSPEECH_H
 
 // Qt includes
 #include <QtCore/QObject>
@@ -51,14 +52,16 @@ public:
     /**
     * @enum JobPriority
     * Determines the priority of jobs submitted by @ref say.
+    * maps directly to SPDPriority
     */
     enum JobPriority
     {
         jpAll                = 0,    /**< All priorities.  Used for information retrieval only. */
-        jpScreenReaderOutput = 1,    /**< Screen Reader job. */
-        jpWarning            = 2,    /**< Warning job. */
-        jpMessage            = 3,    /**< Message job.*/
-        jpText               = 4     /**< Text job. */
+        jpScreenReaderOutput = 1,    /**< Screen Reader job. SPD_IMPORTANT */
+        jpWarning            = 2,    /**< Warning job. SPD_NOTIFICATION */
+        jpMessage            = 3,    /**< Message job.SPD_MESSAGE */
+        jpText               = 4,    /**< Text job. SPD_TEXT */
+        jpProgress           = 5     /**< Progress report. SPD_PROGRESS added KDE 4.4 */ 
     };
     
     /**
@@ -87,7 +90,6 @@ public:
         soPlainText = 0x0001,   /**< The text contains plain text. */
         soHtml      = 0x0002,   /**< The text contains HTML markup. */
         soSsml      = 0x0004,   /**< The text contains SSML markup. */
-        // FUTURE:
         soChar      = 0x0008,   /**< The text should be spoken as individual characters. */
         soKey       = 0x0010,   /**< The text contains a keyboard symbolic key name. */
         soSoundIcon = 0x0020    /**< The text is the name of a sound icon. */
@@ -191,6 +193,7 @@ public Q_SLOTS: // METHODS
     * @return               Version number string.
     */
     QString version() const;
+
     /**
     * Returns the friendly display name for the application.
     * @return               Application display name.
@@ -390,6 +393,22 @@ public Q_SLOTS: // METHODS
     */
     void resume();
 
+    
+    void stop();
+    void cancel();
+
+    QStringList outputModules();
+    QStringList languagesByModule(const QString & module);
+
+    // runtime slots to change the current speech configuration
+    void setSpeed(int speed);
+    void setPitch(int pitch);
+    void setVolume(int volume);
+
+    void setOutputModule(const QString & module);
+    void setLanguage(const QString & language);
+    void setVoiceType(int voiceType);
+
     /**
     * Removes the specified job.  If the job is speaking, it is stopped.
     * @param jobNum             Job Number.  If 0, the last job submitted by
@@ -608,7 +627,12 @@ public Q_SLOTS: // METHODS
     * Shuts down KTTSD.  Do not call this!
     */
     void kttsdExit();
-    
+
+    /**
+    * post ctor helper method that instantiates the dbus adaptor class, and registers
+    */
+    void init();
+
     /**
     * Cause KTTSD to re-read its configuration.
     */
@@ -677,6 +701,7 @@ private:
 
     /*
     * Create and initialize the SpeechData object.
+    * Deprecated, remove in KDE 5
     */
     bool initializeSpeechData();
 
@@ -712,4 +737,4 @@ private:
     KSpeechPrivate* d;
 };
 
-#endif // _KSPEECH_H_
+#endif // KSPEECH_H
